@@ -2,12 +2,12 @@ from typing import Any
 from CxAdmin.api.cxItem import CxItem
 
 
-class CxEnvironment(CxItem):
+class CxEnvironment(CxItem[Any]):
     def getTenant(self) -> Any:
-        raise NotImplementedError()
+        return self._httpClient.get(self._path).json()
 
     def getRegions(self) -> Any:
-        raise NotImplementedError()
+        return self._httpClient.get(f"{self._path}/regions").json()
 
     def get(self) -> Any:
-        return self._httpClient.get(self._path).json()
+        return self.getTenant()
