@@ -1,10 +1,10 @@
 from typing import Any
 from CxAdmin.api.cxItem import CxItem
-from CxAdmin.objects.cxList import CxList
+from CxAdmin.objects.__cxList import CxList
 import json
 
 
-class CxLists(CxItem):
+class CxLists(CxItem[CxList]):
     def get(self) -> list[CxList]:
         listsJson: list[dict[str, Any]] = self._httpClient.get(self._path).json()[
             "result"
@@ -29,7 +29,7 @@ class CxLists(CxItem):
     def uploadList(self, list: CxList) -> dict[str, Any]:
         return self.uploadListCSV(
             list.id,
-            list.constructDataCSV(),
+            list.toCSV(),
         )
 
     def getListCSV(self, listId: str) -> Any:
