@@ -3,7 +3,7 @@ from typing import Any
 from CxAdmin.api.cxItem import CxItem
 
 
-class CxStatistics(CxItem):
+class CxStatistics(CxItem[dict[str, Any]]):
     def getInteractions(
         self, between: tuple[datetime, datetime]
     ) -> list[dict[str, Any]]:
@@ -22,5 +22,8 @@ class CxStatistics(CxItem):
 
         return responsesJsons
 
-    def get(self) -> Any:
-        raise NotImplementedError()
+    def get(self) -> list[dict[str, Any]]:
+        statsJson: list[dict[str, Any]] = self._httpClient.get(
+            f"{self._path}/statistics"
+        ).json()["result"]
+        return statsJson
