@@ -1,9 +1,9 @@
 from typing import Any
 from CxAdmin.api.cxItem import CxItem
-from CxAdmin.objects.cxUser import CxUser
+from CxAdmin.objects.__cxUser import CxUser
 
 
-class CxUsers(CxItem):
+class CxUsers(CxItem[CxUser]):
     def getAllUsers(self) -> list[CxUser]:
         usersJson: list[dict[str, Any]] = self._httpClient.get(self._path).json()[
             "result"
@@ -12,4 +12,4 @@ class CxUsers(CxItem):
         return users
 
     def get(self) -> Any:
-        raise NotImplementedError()
+        return self.getAllUsers()
